@@ -101,7 +101,7 @@ def CheckPMinGSMM(model, PM_df, EX_Sub_Off=['EX_glc__D_e']):
             Sub_eIdx = np.where([Sub_e==met.id for met in model.metabolites])[0]
             Sub_cIdx = np.where([Sub_c==met.id for met in model.metabolites])[0]
             # testing whether biolog metabolite is extracellular or cytoplasmic
-            if Sub_cIdx.size>0 and Sub_eIdx.size>0: 
+            if Sub_eIdx.size>0: # and Sub_cIdx.size>0 
                 # metabolite is extracellular, 
                 # existence of exchange reaction unclear
                 EX_SubRct = 'EX_{}'.format(Sub_e)
@@ -165,3 +165,63 @@ def CheckWellinGSMM(myGrowth, myBool):
     elif not myBool and np.isnan(myGrowth):
 #        no growth in well and model lacks metabolite     
         return 0
+
+def MetSharedRcts(model, Met1, Met2):
+    '''
+    This function lists all reactions which are shared by two metabolites
+    
+    Parameters
+    ----------
+    model : cobra model
+        The cobra model for analysis.
+    Met1 : str
+        Metabolite id.
+    Met2 : str
+        Metabolite id.
+
+    Returns
+    -------
+    list, List of shared reactions.
+
+    '''
+    return [reaction for reaction in model.metabolites.get_by_id(Met1).reactions if reaction in model.metabolites.get_by_id(Met2).reactions]
+
+def MetFluxConnect(model, Met1, Met2, SubOff='EX_glc__D_e', ngam='NGAM', slim=True):
+    '''
+    Test whether there exists a flux between two metabolites. The first metabolite is set as source and FBA is optimized to the second metabolite.
+
+    Parameters
+    ----------
+    model : cobra model
+        .
+        The cobra model for analysis.
+    Met1 : str
+        Metabolite id.
+    Met2 : str
+        Metabolite id.
+    SubOff: str
+        Substrate id to be set to zero
+    ngam: str
+        non growth associated maintenance to be set to zero, because checking close metabolites might not fullfill the base ATP demand in ngam
+    slim : Boolean
+        Decision whether only the value of the objective is reported via slim_optimize, or the full flux-reaction list.
+
+    Returns
+    -------
+    list, List of reactions and flux values.
+
+    '''
+    with model:
+        medium = model.medium
+        medium[SubOff] = 0
+        model.medium = medium
+        model.add_boundary(model.metabolites.get_by_id(Met1), type='sink')        
+        model.add_boundary(model.metabolites.get_by_id(Met2), type='sink')
+        model.reactions.get_by_id(ngam).lower_bound = 0
+        model.objective = 'SK_{}'.format(Met2)
+        if slim:
+            flux = model.slim_optimize()
+        else:
+            flux = model.optimize()
+            
+        return flux
\ No newline at end of file
